.. _dataset:

=========================================
Description of datasets (`skhep.dataset`)
=========================================

.. automodule:: skhep.dataset
   :members:

.. automodule:: skhep.dataset.defs
   :members:

.. automodule:: skhep.dataset.numpydataset
   :members:

.. automodule:: skhep.dataset.rootdataset
   :members:
